@@ -65,12 +65,7 @@ class BaseNetworkdTest(unittest.TestCase):
         # Bandit complains about Jinja2 autoescaping without nosec.
         self.env = jinja2.Environment()  # nosec
         self.env.filters['bool'] = to_bool
-        self.variables.update({
-            'ansible_facts': {
-                'os_family': 'Debian',
-                'distribution_major_version': '22'
-            }
-        })
+        self.variables.update({'ansible_facts': {'os_family': 'Debian'}})
         self.context = self._make_context(self.variables)
 
     def _make_context(self, parent):
